//
//  BaseViewController.m
//  RaisedCenterTabBar
//
//  Created by Peter Boctor on 12/15/10.
//
// Copyright (c) 2011 Peter Boctor
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE
//

#import "BaseViewController.h"
#import "BWAppDelegate.h"

@implementation BaseViewController

// Create a view controller and setup it's tab bar item with a title and image
-(UIViewController*) viewControllerWithTabTitle:(NSString*) title image:(UIImage*)image
{
    UIViewController* viewController = [[UIViewController alloc] init];
    viewController.tabBarItem = [[UITabBarItem alloc] initWithTitle:title image:image tag:0];
    return viewController;
}

// Create a custom UIButton and add it to the center of our tab bar
-(void) addCenterButtonWithOptions:(NSDictionary *)options {
    UIImage *buttonImage = [[BWAppDelegate instance].colorSwitcher getImageWithName:[options objectForKey:@"buttonImage"]];
    UIImage *highlightImage = [UIImage imageNamed:[options objectForKey:@"highlightImage"]];
    UIButton* button = [UIButton buttonWithType:UIButtonTypeCustom];
    button.autoresizingMask = UIViewAutoresizingFlexibleRightMargin | UIViewAutoresizingFlexibleLeftMargin | UIViewAutoresizingFlexibleBottomMargin | UIViewAutoresizingFlexibleTopMargin;
    button.frame = CGRectMake(0.0, 0.0, buttonImage.size.width, buttonImage.size.height);
    [button setBackgroundImage:buttonImage forState:UIControlStateNormal];
    [button setBackgroundImage:highlightImage forState:UIControlStateHighlighted];
    [button addTarget:self action:@selector(showModalController) forControlEvents:UIControlEventTouchUpInside];
    
    CGFloat heightDifference = buttonImage.size.height - self.tabBar.frame.size.height;
    if (heightDifference < 0)
        button.center = self.tabBar.center;
    else {
        CGPoint center = self.tabBar.center;
        center.y = center.y - heightDifference/2.0;
        button.center = center;
    }
    
    UILabel *lblName = [[UILabel alloc] initWithFrame:CGRectMake(3, buttonImage.size.height-14, buttonImage.size.width - 6, 14)];
    lblName.text = [options objectForKey:@"title"];
    lblName.font = [UIFont boldSystemFontOfSize:10.0f];
    lblName.textAlignment = UITextAlignmentCenter;
    lblName.textColor = [UIColor whiteColor];
    lblName.backgroundColor = [UIColor clearColor];
    [button addSubview:lblName];
    
    UIImageView *imgIcon = [[UIImageView alloc] initWithFrame:CGRectMake(3, 3, buttonImage.size.width - 6, buttonImage.size.height - lblName.bounds.size.height - 3)];
    imgIcon.contentMode = UIViewContentModeCenter;
    imgIcon.image = [UIImage imageNamed:[options objectForKey:@"icon"]];
    [button addSubview:imgIcon];
    
    [self.view addSubview:button];
}

- (void)showModalController {
    UIViewController *modal = [self.storyboard instantiateViewControllerWithIdentifier:@"cameraModalViewController"];
    [self presentModalViewController:modal animated:YES];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

@end
